
This is a plan for next incompatible changes - they are primarily renames.

TODO:
*   Introduce `@/data/` dir. And make importable yaml (e.g. from `@/data/`) for server config.

*   TODO: Move `argrelay_client` and `argrelay_server` out of `@/bin/` because multiple servers will clash in PATH.
          OR... Will it still work (simply the last added will be invoked, but it invoked via symlinks -> always correct one)? If yes, keep it.

*   Rename `deploy` in some config/script files to `install`.

*   TODO: Rename rest API:
    *   `describe_line_args` -> `query_enum_items` (to match func_id)
    *   `propose_arg_values` -> `complete_line`
    *   `relay_line_args` -> `invoke_line`

*   TODO: Rename: `relay_demo` to something not cut-off `relay`, at least, both `a` and `r` (something `*ar*`) should be included.
          Something unique yet single word better containing `a` and `r`.

*   TODO: Rename: `argrelay.server.*` -> `argrelay_server` (to search `argrelay_server` and find relevant stuff).
*   TODO: Rename: `argrelay_client.*` -> `argrelay_client` (to search `argrelay_client` and find relevant stuff).
*   TODO: Rename: `relay_server` package to `argrelay_server` (to search `argrelay_server` and find relevant stuff).
*   TODO: Rename: `relay_client` package to `argrelay_client` (to search `argrelay_client` and find relevant stuff).

TODO: Decide `[script].conf` vs `[script].conf.bash` ? I think 2nd is more systematic.

*   TODO: Rename: `@/conf/python_conf.bash` -> `@/conf/python_env.conf.bash`
*   TODO: Rename: `@/conf/argrelay_rc_conf.bash` -> `@/conf/argrelay_client.conf.bash`
*   TODO: Rename: `@/exe/deploy_config_files_conf.bash` -> `@/exe/install_config_files.conf.bash`

TODO:
*   Rename all enum items to underscore (e.g. `ServerAction.ProposeArgValues` -> `ServerAction.propse_args_values`).
*   Consider renaming URL, for example (`_` to `-`, shorten, rethink):
    *   propose_arg_values -> propose-options
    *   describe_line_args -> enum-options
    *   relay_line_args -> invoke-with-options

TODO:
*   Move all GUI config into DefaultConfigurator (including banner).

TODO:
*   TODO: Rename all `func_id` to be prefixed with `func_id`, for example, `query_enum_items_func` -> `func_id_query_enum_items`.
*   Rename: prefix all `func_id` with `func_id`, for example: `goto_service_func` -> `func_id_goto_service`

